.. include:: ../BADGES.rst

Command Line
============

Help::

    swmmtoolbox --help

about
~~~~~
.. program-output:: swmmtoolbox about --help
   :prompt:

catalog
~~~~~~~
.. program-output:: swmmtoolbox catalog --help
   :prompt:

extract
~~~~~~~
.. program-output:: swmmtoolbox extract --help
   :prompt:

listdetail
~~~~~~~~~~
.. program-output:: swmmtoolbox listdetail --help
   :prompt:

listvariables
~~~~~~~~~~~~~
.. program-output:: swmmtoolbox listvariables --help
   :prompt:

stdtoswmm5
~~~~~~~~~~
.. program-output:: swmmtoolbox stdtoswmm5 --help
   :prompt:
